You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/01 08:27:13 UTC

svn commit: r1208981 [13/24] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mai...

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrefixMethodInvocationUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrefixMethodInvocationUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDriven.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDriven.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ModelDriven;
+import org.apache.struts2.xwork2.ModelDriven;
 
 /**
  * Adds the ability to set a model, probably retrieved from a given state.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDrivenInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDrivenInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDrivenInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDrivenInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.inject.Inject;
 
 import java.lang.reflect.Method;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/StaticParametersInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/StaticParametersInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/StaticParametersInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/StaticParametersInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,18 +13,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.Parameterizable;
-import com.opensymphony.xwork2.util.*;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextState;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.Parameterizable;
+import org.apache.struts2.xwork2.util.*;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextState;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.Collections;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/TimerInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/TimerInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/TimerInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/TimerInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: description -->

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ValidationWorkflowAware.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ValidationWorkflowAware.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ValidationWorkflowAware.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ValidationWorkflowAware.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
 /**
  * <code>ValidationWorkflowAware</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionInvocation.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionInvocation.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionInvocation.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionInvocation.java Thu Dec  1 07:18:07 2011
@@ -14,11 +14,11 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.mock;
+package org.apache.struts2.xwork2.mock;
 
-import com.opensymphony.xwork2.*;
-import com.opensymphony.xwork2.interceptor.PreResultListener;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.*;
+import org.apache.struts2.xwork2.interceptor.PreResultListener;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionProxy.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionProxy.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionProxy.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockActionProxy.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.mock;
+package org.apache.struts2.xwork2.mock;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
 
 /**
  * Mock for an {@link ActionProxy}.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockObjectTypeDeterminer.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockObjectTypeDeterminer.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.mock;
+package org.apache.struts2.xwork2.mock;
 
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
 import ognl.OgnlException;
 import ognl.OgnlRuntime;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockResult.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.mock;
+package org.apache.struts2.xwork2.mock;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
 
 /**
  * Mock for a {@link Result}.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ErrorMessageBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ErrorMessageBuilder.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ErrorMessageBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ErrorMessageBuilder.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
 /**
  * Helper class to build error messages.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ObjectProxy.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ObjectProxy.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ObjectProxy.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/ObjectProxy.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
 /**
  * An Object to use within OGNL to proxy other Objects

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlNullHandlerWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlNullHandlerWrapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlNullHandlerWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlNullHandlerWrapper.java Thu Dec  1 07:18:07 2011
@@ -1,6 +1,6 @@
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.conversion.NullHandler;
+import org.apache.struts2.xwork2.conversion.NullHandler;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionContextFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionContextFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionContextFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionContextFactory.java Thu Dec  1 07:18:07 2011
@@ -1,6 +1,6 @@
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.util.reflection.ReflectionContextFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextFactory;
 import ognl.Ognl;
 
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionProvider.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlReflectionProvider.java Thu Dec  1 07:18:07 2011
@@ -1,8 +1,8 @@
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 import ognl.Ognl;
 import ognl.OgnlException;
 import ognl.OgnlRuntime;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlTypeConverterWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlTypeConverterWrapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlTypeConverterWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlTypeConverterWrapper.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.conversion.TypeConverter;
+import org.apache.struts2.xwork2.conversion.TypeConverter;
 
 import java.lang.reflect.Member;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStack.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStack.java Thu Dec  1 07:18:07 2011
@@ -13,23 +13,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.ognl.accessor.CompoundRootAccessor;
-import com.opensymphony.xwork2.util.ClearableValueStack;
-import com.opensymphony.xwork2.util.CompoundRoot;
-import com.opensymphony.xwork2.util.MemberAccessValueStack;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.logging.LoggerUtils;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextState;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ognl.accessor.CompoundRootAccessor;
+import org.apache.struts2.xwork2.util.ClearableValueStack;
+import org.apache.struts2.xwork2.util.CompoundRoot;
+import org.apache.struts2.xwork2.util.MemberAccessValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.LoggerUtils;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextState;
 import ognl.NoSuchPropertyException;
 import ognl.Ognl;
 import ognl.OgnlContext;
@@ -106,21 +106,21 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#getContext()
+     * @see org.apache.struts2.xwork2.util.ValueStack#getContext()
      */
     public Map<String, Object> getContext() {
         return context;
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#setDefaultType(java.lang.Class)
+     * @see org.apache.struts2.xwork2.util.ValueStack#setDefaultType(java.lang.Class)
      */
     public void setDefaultType(Class defaultType) {
         this.defaultType = defaultType;
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#setExprOverrides(java.util.Map)
+     * @see org.apache.struts2.xwork2.util.ValueStack#setExprOverrides(java.util.Map)
      */
     public void setExprOverrides(Map<Object, Object> overrides) {
         if (this.overrides == null) {
@@ -131,28 +131,28 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#getExprOverrides()
+     * @see org.apache.struts2.xwork2.util.ValueStack#getExprOverrides()
      */
     public Map<Object, Object> getExprOverrides() {
         return this.overrides;
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#getRoot()
+     * @see org.apache.struts2.xwork2.util.ValueStack#getRoot()
      */
     public CompoundRoot getRoot() {
         return root;
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#setValue(java.lang.String, java.lang.Object)
+     * @see org.apache.struts2.xwork2.util.ValueStack#setValue(java.lang.String, java.lang.Object)
      */
     public void setValue(String expr, Object value) {
         setValue(expr, value, devMode);
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#setValue(java.lang.String, java.lang.Object, boolean)
+     * @see org.apache.struts2.xwork2.util.ValueStack#setValue(java.lang.String, java.lang.Object, boolean)
      */
     public void setValue(String expr, Object value, boolean throwExceptionOnFailure) {
         Map<String, Object> context = getContext();
@@ -203,7 +203,7 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#findString(java.lang.String)
+     * @see org.apache.struts2.xwork2.util.ValueStack#findString(java.lang.String)
      */
     public String findString(String expr) {
         return (String) findValue(expr, String.class);
@@ -214,7 +214,7 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#findValue(java.lang.String)
+     * @see org.apache.struts2.xwork2.util.ValueStack#findValue(java.lang.String)
      */
     public Object findValue(String expr, boolean throwExceptionOnFailure) {
         try {
@@ -285,7 +285,7 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#findValue(java.lang.String, java.lang.Class)
+     * @see org.apache.struts2.xwork2.util.ValueStack#findValue(java.lang.String, java.lang.Class)
      */
     public Object findValue(String expr, Class asType, boolean throwExceptionOnFailure) {
         try {
@@ -367,28 +367,28 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#peek()
+     * @see org.apache.struts2.xwork2.util.ValueStack#peek()
      */
     public Object peek() {
         return root.peek();
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#pop()
+     * @see org.apache.struts2.xwork2.util.ValueStack#pop()
      */
     public Object pop() {
         return root.pop();
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#push(java.lang.Object)
+     * @see org.apache.struts2.xwork2.util.ValueStack#push(java.lang.Object)
      */
     public void push(Object o) {
         root.push(o);
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#set(java.lang.String, java.lang.Object)
+     * @see org.apache.struts2.xwork2.util.ValueStack#set(java.lang.String, java.lang.Object)
      */
     public void set(String key, Object o) {
         //set basically is backed by a Map pushed on the stack with a key being put on the map and the Object being the value
@@ -417,7 +417,7 @@ public class OgnlValueStack implements S
     }
 
     /**
-     * @see com.opensymphony.xwork2.util.ValueStack#size()
+     * @see org.apache.struts2.xwork2.util.ValueStack#size()
      */
     public int size() {
         return root.size();

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStackFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStackFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStackFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStackFactory.java Thu Dec  1 07:18:07 2011
@@ -13,18 +13,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.conversion.NullHandler;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.ognl.accessor.CompoundRootAccessor;
-import com.opensymphony.xwork2.util.CompoundRoot;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.conversion.NullHandler;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ognl.accessor.CompoundRootAccessor;
+import org.apache.struts2.xwork2.util.CompoundRoot;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
 import ognl.MethodAccessor;
 import ognl.OgnlRuntime;
 import ognl.PropertyAccessor;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/SecurityMemberAccess.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/SecurityMemberAccess.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/SecurityMemberAccess.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/SecurityMemberAccess.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
 import ognl.DefaultMemberAccess;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/XWorkTypeConverterWrapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/XWorkTypeConverterWrapper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/XWorkTypeConverterWrapper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/XWorkTypeConverterWrapper.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.conversion.TypeConverter;
+import org.apache.struts2.xwork2.conversion.TypeConverter;
 
 import java.lang.reflect.Member;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringObjectFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringObjectFactory.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.spring;
+package org.apache.struts2.xwork2.spring;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.springframework.beans.BeansException;
 import org.springframework.beans.factory.UnsatisfiedDependencyException;
 import org.springframework.beans.factory.config.AutowireCapableBeanFactory;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringProxyableObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringProxyableObjectFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringProxyableObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/spring/SpringProxyableObjectFactory.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.spring;
+package org.apache.struts2.xwork2.spring;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.springframework.beans.factory.NoSuchBeanDefinitionException;
 import org.springframework.beans.factory.support.BeanDefinitionRegistry;
 import org.springframework.beans.factory.support.RootBeanDefinition;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/test/StubConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/test/StubConfigurationProvider.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/test/StubConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/test/StubConfigurationProvider.java Thu Dec  1 07:18:07 2011
@@ -1,10 +1,10 @@
-package com.opensymphony.xwork2.test;
+package org.apache.struts2.xwork2.test;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
 
 public class StubConfigurationProvider implements ConfigurationProvider {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassLoaderUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassLoaderUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassLoaderUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassLoaderUtil.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassPathFinder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassPathFinder.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClearableValueStack.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClearableValueStack.java Thu Dec  1 07:18:07 2011
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 /**
  * ValueStacks implementing this interface provide a way to remove values from

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CompoundRoot.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CompoundRoot.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CompoundRoot.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CompoundRoot.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CreateIfNull.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CreateIfNull.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CreateIfNull.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/CreateIfNull.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/DomHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/DomHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/DomHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/DomHelper.java Thu Dec  1 07:18:07 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.util.location.Location;
-import com.opensymphony.xwork2.util.location.LocationAttributes;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.location.LocationAttributes;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Element.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Element.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Element.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Element.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/FileManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/FileManager.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/FileManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/FileManager.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.io.FileUtils;
 
 import java.io.File;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Key.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Key.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Key.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/Key.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/KeyProperty.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/KeyProperty.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/KeyProperty.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/KeyProperty.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/LocalizedTextUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/LocalizedTextUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/LocalizedTextUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/LocalizedTextUtil.java Thu Dec  1 07:18:07 2011
@@ -19,15 +19,15 @@
  * under the License.
  */
 
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ModelDriven;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionProviderFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ModelDriven;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProviderFactory;
 import org.apache.commons.lang.ObjectUtils;
 
 import java.beans.PropertyDescriptor;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/MemberAccessValueStack.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/MemberAccessValueStack.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/MemberAccessValueStack.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/MemberAccessValueStack.java Thu Dec  1 07:18:07 2011
@@ -1,4 +1,4 @@
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.Set;
 import java.util.regex.Pattern;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/NamedVariablePatternMatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/NamedVariablePatternMatcher.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/NamedVariablePatternMatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/NamedVariablePatternMatcher.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.ArrayList;
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PatternMatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PatternMatcher.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PatternMatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PatternMatcher.java Thu Dec  1 07:18:07 2011
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PropertiesReader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PropertiesReader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PropertiesReader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/PropertiesReader.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.io.*;
 import java.util.ArrayList;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ResolverUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ResolverUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/TextParseUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/TextParseUtil.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Container;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Container;
 
 import java.util.HashSet;
 import java.util.Set;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/URLUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/URLUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/URLUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/URLUtil.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.regex.Pattern;
 import java.util.regex.Matcher;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStack.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStack.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStack.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStack.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStackFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStackFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStackFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ValueStackFactory.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 /**
  * Factory that creates a value stack, defaulting to the OgnlValueStackFactory
@@ -21,17 +21,17 @@ package com.opensymphony.xwork2.util;
 public interface ValueStackFactory {
 
     /**
-     * Get a new instance of {@link com.opensymphony.xwork2.util.ValueStack}
+     * Get a new instance of {@link org.apache.struts2.xwork2.util.ValueStack}
      *
-     * @return  a new {@link com.opensymphony.xwork2.util.ValueStack}.
+     * @return  a new {@link org.apache.struts2.xwork2.util.ValueStack}.
      */
     ValueStack createValueStack();
     
     /**
-     * Get a new instance of {@link com.opensymphony.xwork2.util.ValueStack}
+     * Get a new instance of {@link org.apache.struts2.xwork2.util.ValueStack}
      *
      * @param stack an existing stack to include.
-     * @return  a new {@link com.opensymphony.xwork2.util.ValueStack}.
+     * @return  a new {@link org.apache.struts2.xwork2.util.ValueStack}.
      */
     ValueStack createValueStack(ValueStack stack);
     

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardHelper.java Thu Dec  1 07:18:07 2011
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/WildcardUtil.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
 import java.util.regex.Pattern;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkList.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkList.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkList.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkList.java Thu Dec  1 07:18:07 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.ArrayList;
 import java.util.Collection;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkTestCaseHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkTestCaseHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkTestCaseHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/XWorkTestCaseHelper.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.*;
-import com.opensymphony.xwork2.config.providers.XWorkConfigurationProvider;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.*;
+import org.apache.struts2.xwork2.config.providers.XWorkConfigurationProvider;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
 
 /**
  * Generic test setup methods to be used with any unit testing framework. 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/FileResourceStore.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/FileResourceStore.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/FileResourceStore.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/FileResourceStore.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.classloader;
+package org.apache.struts2.xwork2.util.classloader;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.File;
 import java.io.FileInputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/JarResourceStore.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/JarResourceStore.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/JarResourceStore.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/JarResourceStore.java Thu Dec  1 07:18:07 2011
@@ -14,10 +14,10 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.util.classloader;
+package org.apache.struts2.xwork2.util.classloader;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.*;
 import java.util.zip.ZipEntry;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ReloadingClassLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ReloadingClassLoader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ReloadingClassLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ReloadingClassLoader.java Thu Dec  1 07:18:07 2011
@@ -13,13 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.classloader;
+package org.apache.struts2.xwork2.util.classloader;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.classloader.FileResourceStore;
-import com.opensymphony.xwork2.util.URLUtil;
-import com.opensymphony.xwork2.XWorkException;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.URLUtil;
+import org.apache.struts2.xwork2.XWorkException;
 
 import java.io.InputStream;
 import java.io.File;
@@ -29,8 +28,6 @@ import java.util.regex.Pattern;
 import java.util.regex.Matcher;
 import java.util.Set;
 import java.util.Collections;
-import java.util.Collection;
-import java.util.HashSet;
 
 import org.apache.commons.lang.ObjectUtils;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStore.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStore.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStore.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStore.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.classloader;
+package org.apache.struts2.xwork2.util.classloader;
 
 /**
  * *interface taken from Apache JCI

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStoreClassLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStoreClassLoader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStoreClassLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/classloader/ResourceStoreClassLoader.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.classloader;
+package org.apache.struts2.xwork2.util.classloader;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * class taken from Apache JCI

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassFinder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassFinder.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassFinder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassFinder.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.finder;
+package org.apache.struts2.xwork2.util.finder;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.URLUtil;
-import com.opensymphony.xwork2.XWorkException;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.URLUtil;
+import org.apache.struts2.xwork2.XWorkException;
 import org.objectweb.asm.AnnotationVisitor;
 import org.objectweb.asm.ClassReader;
 import org.objectweb.asm.FieldVisitor;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterface.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterface.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterface.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterface.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.finder;
+package org.apache.struts2.xwork2.util.finder;
 
 import java.net.URL;
 import java.util.Enumeration;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterfaceDelegate.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterfaceDelegate.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterfaceDelegate.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ClassLoaderInterfaceDelegate.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.finder;
+package org.apache.struts2.xwork2.util.finder;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ResourceFinder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ResourceFinder.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ResourceFinder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/ResourceFinder.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.finder;
+package org.apache.struts2.xwork2.util.finder;
 
 import org.apache.commons.lang.StringUtils;
 
@@ -26,8 +26,8 @@ import java.util.*;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * @author David Blevins

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/Test.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/Test.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/Test.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/Test.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.finder;
+package org.apache.struts2.xwork2.util.finder;
 
 /**
  * This is the testing interface that is used to accept or reject resources.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/UrlSet.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/UrlSet.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/UrlSet.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/finder/UrlSet.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.finder;
+package org.apache.struts2.xwork2.util.finder;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.URLUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.URLUtil;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.ObjectUtils;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Locatable.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Locatable.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Locatable.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Locatable.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
 /**
  * A interface that should be implemented by objects knowning their location (i.e. where they

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocatableProperties.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocatableProperties.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocatableProperties.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocatableProperties.java Thu Dec  1 07:18:07 2011
@@ -1,6 +1,6 @@
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
-import com.opensymphony.xwork2.util.PropertiesReader;
+import org.apache.struts2.xwork2.util.PropertiesReader;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Located.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Located.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Located.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Located.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
 /**
  * Base class for location aware objects

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Location.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Location.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Location.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/Location.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
 import java.util.List;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationAttributes.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationAttributes.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationAttributes.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationAttributes.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
 import org.w3c.dom.Attr;
 import org.w3c.dom.Element;
@@ -27,7 +27,7 @@ import org.xml.sax.helpers.AttributesImp
 
 /**
  * A class to handle location information stored in attributes.
- * These attributes are typically setup using {@link com.opensymphony.xwork2.util.location.LocationAttributes.Pipe}
+ * These attributes are typically setup using {@link org.apache.struts2.xwork2.util.location.LocationAttributes.Pipe}
  * which augments the SAX stream with additional attributes, e.g.:
  * <pre>
  * &lt;root xmlns:loc="http://struts.apache.org/xwork/location"
@@ -37,7 +37,7 @@ import org.xml.sax.helpers.AttributesImp
  * &lt;/root&gt;
  * </pre>
  * 
- * @see com.opensymphony.xwork2.util.location.LocationAttributes.Pipe
+ * @see org.apache.struts2.xwork2.util.location.LocationAttributes.Pipe
  * @since 2.1.8
  * @version $Id$
  */
@@ -275,7 +275,7 @@ public class LocationAttributes {
      * the overhead in SAX events is not that big, as attribute names are interned, and all <code>src</code>
      * attributes point to the same string.
      * 
-     * @see com.opensymphony.xwork2.util.location.LocationAttributes
+     * @see org.apache.struts2.xwork2.util.location.LocationAttributes
      */
     public static class Pipe implements ContentHandler {
         

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationImpl.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationImpl.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationImpl.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/location/LocationImpl.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util.location;
+package org.apache.struts2.xwork2.util.location;
 
 import java.io.BufferedReader;
 import java.io.InputStream;
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrefixMethodInvocationUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrefixMethodInvocationUtil.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -36,7 +36,7 @@ import java.lang.reflect.Method;
  * <!-- START SNIPPET: javadocDefaultWorkflowInterceptor -->
  * 
  * <b>In DefaultWorkflowInterceptor</b>
  * <p>applies only when action implements {@link com.opensymphony.xwork2.Validateable}</p>
  * <ol>
  *    <li>if the action class have validate{MethodName}(), it will be invoked</li>
  *    <li>else if the action class have validateDo{MethodName}(), it will be invoked</li>
@@ -36,7 +36,7 @@ import java.lang.reflect.Method;
  * 
  * <b>In DefaultWorkflowInterceptor</b>
- * <p>applies only when action implements {@link com.opensymphony.xwork2.Validateable}</p>
+ * <p>applies only when action implements {@link org.apache.struts2.xwork2.Validateable}</p>
  * <ol>
  *    <li>if the action class have validate{MethodName}(), it will be invoked</li>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrepareInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrepareInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrepareInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PrepareInterceptor.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Preparable;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Preparable;
 
 import java.lang.reflect.InvocationTargetException;
 
@@ -48,7 +46,7 @@ import java.lang.reflect.InvocationTarge
  * <p/><b>Update</b>: Added logic to execute a prepare{MethodName} and conditionally
  * the a general prepare() Method, depending on the 'alwaysInvokePrepare' parameter/property
  * which is by default true. This allows us to run some logic based on the method
  * name we specify in the {@link com.opensymphony.xwork2.ActionProxy}. For example, you can specify a
  * prepareInput() method that will be run before the invocation of the input method.
  *
  * <!-- END SNIPPET: description -->
@@ -94,7 +92,7 @@ import java.lang.reflect.InvocationTarge
  * @author Jason Carreira
  * @author Philip Luppens
  * @author tm_jee
- * @see com.opensymphony.xwork2.Preparable
+ * @see org.apache.struts2.xwork2.Preparable
  */
 public class PrepareInterceptor extends MethodFilterInterceptor {
 
@@ -48,7 +46,7 @@ import java.lang.reflect.InvocationTarge
  * the a general prepare() Method, depending on the 'alwaysInvokePrepare' parameter/property
  * which is by default true. This allows us to run some logic based on the method
- * name we specify in the {@link com.opensymphony.xwork2.ActionProxy}. For example, you can specify a
+ * name we specify in the {@link org.apache.struts2.xwork2.ActionProxy}. For example, you can specify a
  * prepareInput() method that will be run before the invocation of the input method.
  *

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDriven.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ScopedModelDriven.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.mock;
+package org.apache.struts2.xwork2.mock;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.Interceptor;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.Interceptor;
 import junit.framework.Assert;
 
 
 /**
  * Mock for an {@link com.opensymphony.xwork2.interceptor.Interceptor}.
  *
  * @author Jason Carreira
  */
@@ -13,15 +13,15 @@
 
 /**
- * Mock for an {@link com.opensymphony.xwork2.interceptor.Interceptor}.
+ * Mock for an {@link org.apache.struts2.xwork2.interceptor.Interceptor}.
  *
  * @author Jason Carreira

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockObjectTypeDeterminer.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/mock/MockObjectTypeDeterminer.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlUtil.java Thu Dec  1 07:18:07 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.ognl;
+package org.apache.struts2.xwork2.ognl;
 
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.CompoundRoot;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.CompoundRoot;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
 import ognl.*;
 
 import java.beans.BeanInfo;
@@ -232,7 +232,7 @@ public class OgnlUtil {
 
     /**
      * Copies the properties in the object "from" and sets them in the object "to"
      * using specified type converter, or {@link com.opensymphony.xwork2.conversion.impl.XWorkConverter} if none
      * is specified.
      *
      * @param from       the source object
@@ -306,7 +306,7 @@ public class OgnlUtil {
 
     /**
      * Copies the properties in the object "from" and sets them in the object "to"
      * using specified type converter, or {@link com.opensymphony.xwork2.conversion.impl.XWorkConverter} if none
      * is specified.
      *
      * @param from    the source object
@@ -232,7 +232,7 @@ public class OgnlUtil {
     /**
      * Copies the properties in the object "from" and sets them in the object "to"
-     * using specified type converter, or {@link com.opensymphony.xwork2.conversion.impl.XWorkConverter} if none
+     * using specified type converter, or {@link org.apache.struts2.xwork2.conversion.impl.XWorkConverter} if none
      * is specified.
      *
@@ -306,7 +306,7 @@ public class OgnlUtil {
     /**
      * Copies the properties in the object "from" and sets them in the object "to"
-     * using specified type converter, or {@link com.opensymphony.xwork2.conversion.impl.XWorkConverter} if none
+     * using specified type converter, or {@link org.apache.struts2.xwork2.conversion.impl.XWorkConverter} if none
      * is specified.
      *

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStack.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/ognl/OgnlValueStack.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassPathFinder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClassPathFinder.java Thu Dec  1 07:18:07 2011
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.XWorkException;
+import org.apache.struts2.xwork2.XWorkException;
 
 import java.io.File;
 import java.net.URI;
@@ -30,8 +30,8 @@ import java.util.Vector;
 /**
  * This class is an utility class that will search through the classpath
  * for files whose names match the given pattern. The filename is tested
  * using the given implementation of {@link com.opensymphony.xwork2.util.PatternMatcher} by default it 
  * uses {@link com.opensymphony.xwork2.util.WildcardHelper}
  *
  * @version $Rev$ $Date$
  */
@@ -30,8 +30,8 @@ import java.util.Vector;
  * This class is an utility class that will search through the classpath
  * for files whose names match the given pattern. The filename is tested
- * using the given implementation of {@link com.opensymphony.xwork2.util.PatternMatcher} by default it 
- * uses {@link com.opensymphony.xwork2.util.WildcardHelper}
+ * using the given implementation of {@link org.apache.struts2.xwork2.util.PatternMatcher} by default it
+ * uses {@link org.apache.struts2.xwork2.util.WildcardHelper}
  *
  * @version $Rev$ $Date$

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClearableValueStack.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ClearableValueStack.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ResolverUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/ResolverUtil.java Thu Dec  1 07:18:07 2011
@@ -12,10 +12,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.util;
+package org.apache.struts2.xwork2.util;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -43,7 +43,7 @@ import java.util.jar.JarInputStream;
  * methods.</p>
  *
  * <p>General searches are initiated by calling the
  * {@link #find(com.opensymphony.xwork2.util.ResolverUtil.Test, String...)} ()} method and supplying
  * a package name and a Test instance. This will cause the named package <b>and all sub-packages</b>
  * to be scanned for classes that meet the test. There are also utility methods for the common
  * use cases of scanning multiple packages for extensions of particular classes, or classes
@@ -43,7 +43,7 @@ import java.util.jar.JarInputStream;
  *
  * <p>General searches are initiated by calling the
- * {@link #find(com.opensymphony.xwork2.util.ResolverUtil.Test, String...)} ()} method and supplying
+ * {@link #find(org.apache.struts2.xwork2.util.ResolverUtil.Test, String...)} ()} method and supplying
  * a package name and a Test instance. This will cause the named package <b>and all sub-packages</b>
  * to be scanned for classes that meet the test. There are also utility methods for the common

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/TextParseUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/util/TextParseUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================